@@ -31,15 +31,9 @@ fn main() {
 ```
 */
 
-use fltk::{
-    enums,
-    group::Group,
-    prelude::{GroupExt, WidgetBase, WidgetExt, WidgetType},
-    widget::Widget,
-};
+use fltk::{enums, group::Group, prelude::{GroupExt, WidgetBase, WidgetExt, WidgetType}, widget::Widget, widget_extends};
 use std::{
     mem,
-    ops::{Deref, DerefMut},
 };
 
 /// Defines Flex types
@@ -76,6 +70,25 @@ pub struct Flex {
     debug: bool,
 }
 
+widget_extends!(Flex, Group, grp);
+
+impl Default for Flex {
+    fn default() -> Flex {
+        let dir = FlexType::Row;
+        let margin = 0;
+        let pad = 5;
+        let grp = Group::default().size_of_parent();
+        Flex {
+            grp,
+            dir,
+            margin,
+            pad,
+            setsized: Vec::new(),
+            debug: false,
+        }
+    }
+}
+
 // Code translated from https://github.com/osen/FL_Flex
 impl Flex {
     /// Create a new Flex widget
@@ -94,34 +107,6 @@ impl Flex {
         }
     }
 
-    /// Create a default initialized Flex widget
-    pub fn default() -> Self {
-        let dir = FlexType::Row;
-        let margin = 0;
-        let pad = 5;
-        let grp = Group::default().size_of_parent();
-        Self {
-            grp,
-            dir,
-            margin,
-            pad,
-            setsized: Vec::new(),
-            debug: false,
-        }
-    }
-
-    /// Create a flex with size
-    pub fn with_size(mut self, w: i32, h: i32) -> Self {
-        self.grp.set_size(w, h);
-        self
-    }
-
-    /// Create a default type of flex widget
-    pub fn with_type<T: WidgetType>(mut self, typ: T) -> Self {
-        self.dir = FlexType::from_i32(typ.to_i32());
-        self
-    }
-
     /// Set the direction
     pub fn set_type<T: WidgetType>(&mut self, typ: T) {
         self.dir = FlexType::from_i32(typ.to_i32());
@@ -132,12 +117,29 @@ impl Flex {
         T::from_i32(self.dir.to_i32())
     }
 
+    /// Set the type to be a column
+    pub fn column(mut self) -> Self {
+        self.set_type(FlexType::Column);
+        self
+    }
+
+    /// Set the type to a row
+    pub fn row(mut self) -> Self {
+        self.set_type(FlexType::Row);
+        self
+    }
+
     /// End the Flex widget
     pub fn end(&mut self) {
         self.grp.end();
         self.resize(self.grp.x(), self.grp.y(), self.grp.w(), self.grp.h());
     }
 
+    /// Recalculate children's coords and sizes
+    pub fn recalc(&mut self) {
+        self.end();
+    }
+
     /// Set the size of the widget
     pub fn set_size<W: WidgetExt>(&mut self, wid: &mut W, size: i32) {
         wid.resize(0, 0, size, size);
@@ -269,17 +271,3 @@ impl Flex {
         }
     }
 }
-
-impl Deref for Flex {
-    type Target = Group;
-
-    fn deref(&self) -> &Self::Target {
-        &self.grp
-    }
-}
-
-impl DerefMut for Flex {
-    fn deref_mut(&mut self) -> &mut Self::Target {
-        &mut self.grp
-    }
-}
